# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_dataproc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gcp/gcp_dataproc.proto\x12\x18oak9.tython.gcp.dataproc\x1a\x13shared/shared.proto\"\xde\x01\n3DataprocAutoscalingPolicyXBasicAlgorithmXYarnConfig\x12%\n\x1dgraceful_decommission_timeout\x18\x01 \x01(\t\x12\x19\n\x11scale_down_factor\x18\x02 \x01(\x01\x12&\n\x1escale_down_min_worker_fraction\x18\x03 \x01(\x01\x12\x17\n\x0fscale_up_factor\x18\x04 \x01(\x01\x12$\n\x1cscale_up_min_worker_fraction\x18\x05 \x01(\x01\"\xa7\x01\n(DataprocAutoscalingPolicyXBasicAlgorithm\x12\x17\n\x0f\x63ooldown_period\x18\x01 \x01(\t\x12\x62\n\x0byarn_config\x18\x02 \x01(\x0b\x32M.oak9.tython.gcp.dataproc.DataprocAutoscalingPolicyXBasicAlgorithmXYarnConfig\"o\n/DataprocAutoscalingPolicyXSecondaryWorkerConfig\x12\x15\n\rmax_instances\x18\x01 \x01(\x01\x12\x15\n\rmin_instances\x18\x02 \x01(\x01\x12\x0e\n\x06weight\x18\x03 \x01(\x01\"T\n\"DataprocAutoscalingPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"f\n&DataprocAutoscalingPolicyXWorkerConfig\x12\x15\n\rmax_instances\x18\x01 \x01(\x01\x12\x15\n\rmin_instances\x18\x02 \x01(\x01\x12\x0e\n\x06weight\x18\x03 \x01(\x01\"\x96\x04\n\x19\x44\x61taprocAutoscalingPolicy\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tpolicy_id\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12[\n\x0f\x62\x61sic_algorithm\x18\x06 \x01(\x0b\x32\x42.oak9.tython.gcp.dataproc.DataprocAutoscalingPolicyXBasicAlgorithm\x12j\n\x17secondary_worker_config\x18\x07 \x01(\x0b\x32I.oak9.tython.gcp.dataproc.DataprocAutoscalingPolicyXSecondaryWorkerConfig\x12N\n\x08timeouts\x18\x08 \x01(\x0b\x32<.oak9.tython.gcp.dataproc.DataprocAutoscalingPolicyXTimeouts\x12W\n\rworker_config\x18\t \x01(\x0b\x32@.oak9.tython.gcp.dataproc.DataprocAutoscalingPolicyXWorkerConfig\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"g\n-DataprocAutoscalingPolicyIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xa9\x02\n#DataprocAutoscalingPolicyIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x11\n\tpolicy_id\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12Z\n\tcondition\x18\x08 \x01(\x0b\x32G.oak9.tython.gcp.dataproc.DataprocAutoscalingPolicyIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"f\n,DataprocAutoscalingPolicyIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xa6\x02\n\"DataprocAutoscalingPolicyIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x11\n\tpolicy_id\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12Y\n\tcondition\x18\x08 \x01(\x0b\x32\x46.oak9.tython.gcp.dataproc.DataprocAutoscalingPolicyIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc2\x01\n\"DataprocAutoscalingPolicyIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x11\n\tpolicy_id\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"E\n/DataprocClusterXClusterConfigXAutoscalingConfig\x12\x12\n\npolicy_uri\x18\x01 \x01(\t\"F\n.DataprocClusterXClusterConfigXEncryptionConfig\x12\x14\n\x0ckms_key_name\x18\x01 \x01(\t\"\xec\x01\n,DataprocClusterXClusterConfigXEndpointConfig\x12\x1f\n\x17\x65nable_http_port_access\x18\x01 \x01(\x08\x12i\n\nhttp_ports\x18\x02 \x03(\x0b\x32U.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXEndpointConfig.HttpPortsEntry\x1a\x30\n\x0eHttpPortsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9d\x01\nEDataprocClusterXClusterConfigXGceClusterConfigXShieldedInstanceConfig\x12#\n\x1b\x65nable_integrity_monitoring\x18\x01 \x01(\x08\x12\x1a\n\x12\x65nable_secure_boot\x18\x02 \x01(\x08\x12\x13\n\x0b\x65nable_vtpm\x18\x03 \x01(\x08\"\xe3\x03\n.DataprocClusterXClusterConfigXGceClusterConfig\x12\x18\n\x10internal_ip_only\x18\x01 \x01(\x08\x12h\n\x08metadata\x18\x02 \x03(\x0b\x32V.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXGceClusterConfig.MetadataEntry\x12\x0f\n\x07network\x18\x03 \x01(\t\x12\x17\n\x0fservice_account\x18\x04 \x01(\t\x12\x1e\n\x16service_account_scopes\x18\x05 \x03(\t\x12\x12\n\nsubnetwork\x18\x06 \x01(\t\x12\x0c\n\x04tags\x18\x07 \x03(\t\x12\x0c\n\x04zone\x18\x08 \x01(\t\x12\x81\x01\n\x18shielded_instance_config\x18\t \x01(\x0b\x32_.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXGceClusterConfigXShieldedInstanceConfig\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Y\n2DataprocClusterXClusterConfigXInitializationAction\x12\x0e\n\x06script\x18\x01 \x01(\t\x12\x13\n\x0btimeout_sec\x18\x02 \x01(\x01\"{\n-DataprocClusterXClusterConfigXLifecycleConfig\x12\x18\n\x10\x61uto_delete_time\x18\x01 \x01(\t\x12\x17\n\x0fidle_delete_ttl\x18\x02 \x01(\t\x12\x17\n\x0fidle_start_time\x18\x03 \x01(\t\"n\n7DataprocClusterXClusterConfigXMasterConfigXAccelerators\x12\x19\n\x11\x61\x63\x63\x65lerator_count\x18\x01 \x01(\x01\x12\x18\n\x10\x61\x63\x63\x65lerator_type\x18\x02 \x01(\t\"\x82\x01\n5DataprocClusterXClusterConfigXMasterConfigXDiskConfig\x12\x19\n\x11\x62oot_disk_size_gb\x18\x01 \x01(\x01\x12\x16\n\x0e\x62oot_disk_type\x18\x02 \x01(\t\x12\x16\n\x0enum_local_ssds\x18\x03 \x01(\x01\"\xed\x02\n*DataprocClusterXClusterConfigXMasterConfig\x12\x11\n\timage_uri\x18\x01 \x01(\t\x12\x16\n\x0einstance_names\x18\x02 \x03(\t\x12\x14\n\x0cmachine_type\x18\x03 \x01(\t\x12\x18\n\x10min_cpu_platform\x18\x04 \x01(\t\x12\x15\n\rnum_instances\x18\x05 \x01(\x01\x12g\n\x0c\x61\x63\x63\x65lerators\x18\x06 \x03(\x0b\x32Q.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXMasterConfigXAccelerators\x12\x64\n\x0b\x64isk_config\x18\x07 \x01(\x0b\x32O.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXMasterConfigXDiskConfig\"S\n-DataprocClusterXClusterConfigXMetastoreConfig\x12\"\n\x1a\x64\x61taproc_metastore_service\x18\x01 \x01(\t\"\x8d\x01\n@DataprocClusterXClusterConfigXPreemptibleWorkerConfigXDiskConfig\x12\x19\n\x11\x62oot_disk_size_gb\x18\x01 \x01(\x01\x12\x16\n\x0e\x62oot_disk_type\x18\x02 \x01(\t\x12\x16\n\x0enum_local_ssds\x18\x03 \x01(\x01\"\xef\x01\n5DataprocClusterXClusterConfigXPreemptibleWorkerConfig\x12\x16\n\x0einstance_names\x18\x01 \x03(\t\x12\x15\n\rnum_instances\x18\x02 \x01(\x01\x12\x16\n\x0epreemptibility\x18\x03 \x01(\t\x12o\n\x0b\x64isk_config\x18\x04 \x01(\x0b\x32Z.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXPreemptibleWorkerConfigXDiskConfig\"\xf2\x03\n;DataprocClusterXClusterConfigXSecurityConfigXKerberosConfig\x12&\n\x1e\x63ross_realm_trust_admin_server\x18\x01 \x01(\t\x12\x1d\n\x15\x63ross_realm_trust_kdc\x18\x02 \x01(\t\x12\x1f\n\x17\x63ross_realm_trust_realm\x18\x03 \x01(\t\x12-\n%cross_realm_trust_shared_password_uri\x18\x04 \x01(\t\x12\x17\n\x0f\x65nable_kerberos\x18\x05 \x01(\x08\x12\x16\n\x0ekdc_db_key_uri\x18\x06 \x01(\t\x12\x18\n\x10key_password_uri\x18\x07 \x01(\t\x12\x1d\n\x15keystore_password_uri\x18\x08 \x01(\t\x12\x14\n\x0ckeystore_uri\x18\t \x01(\t\x12\x13\n\x0bkms_key_uri\x18\n \x01(\t\x12\r\n\x05realm\x18\x0b \x01(\t\x12#\n\x1broot_principal_password_uri\x18\x0c \x01(\t\x12\x1a\n\x12tgt_lifetime_hours\x18\r \x01(\x01\x12\x1f\n\x17truststore_password_uri\x18\x0e \x01(\t\x12\x16\n\x0etruststore_uri\x18\x0f \x01(\t\"\x9e\x01\n,DataprocClusterXClusterConfigXSecurityConfig\x12n\n\x0fkerberos_config\x18\x01 \x01(\x0b\x32U.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXSecurityConfigXKerberosConfig\"\xb9\x03\n,DataprocClusterXClusterConfigXSoftwareConfig\x12\x15\n\rimage_version\x18\x01 \x01(\t\x12\x1b\n\x13optional_components\x18\x02 \x03(\t\x12{\n\x13override_properties\x18\x03 \x03(\x0b\x32^.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXSoftwareConfig.OverridePropertiesEntry\x12j\n\nproperties\x18\x04 \x03(\x0b\x32V.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXSoftwareConfig.PropertiesEntry\x1a\x39\n\x17OverridePropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n7DataprocClusterXClusterConfigXWorkerConfigXAccelerators\x12\x19\n\x11\x61\x63\x63\x65lerator_count\x18\x01 \x01(\x01\x12\x18\n\x10\x61\x63\x63\x65lerator_type\x18\x02 \x01(\t\"\x82\x01\n5DataprocClusterXClusterConfigXWorkerConfigXDiskConfig\x12\x19\n\x11\x62oot_disk_size_gb\x18\x01 \x01(\x01\x12\x16\n\x0e\x62oot_disk_type\x18\x02 \x01(\t\x12\x16\n\x0enum_local_ssds\x18\x03 \x01(\x01\"\xed\x02\n*DataprocClusterXClusterConfigXWorkerConfig\x12\x11\n\timage_uri\x18\x01 \x01(\t\x12\x16\n\x0einstance_names\x18\x02 \x03(\t\x12\x14\n\x0cmachine_type\x18\x03 \x01(\t\x12\x18\n\x10min_cpu_platform\x18\x04 \x01(\t\x12\x15\n\rnum_instances\x18\x05 \x01(\x01\x12g\n\x0c\x61\x63\x63\x65lerators\x18\x06 \x03(\x0b\x32Q.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXWorkerConfigXAccelerators\x12\x64\n\x0b\x64isk_config\x18\x07 \x01(\x0b\x32O.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXWorkerConfigXDiskConfig\"\x92\n\n\x1d\x44\x61taprocClusterXClusterConfig\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x16\n\x0estaging_bucket\x18\x02 \x01(\t\x12\x13\n\x0btemp_bucket\x18\x03 \x01(\t\x12\x65\n\x12\x61utoscaling_config\x18\x04 \x01(\x0b\x32I.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXAutoscalingConfig\x12\x63\n\x11\x65ncryption_config\x18\x05 \x01(\x0b\x32H.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXEncryptionConfig\x12_\n\x0f\x65ndpoint_config\x18\x06 \x01(\x0b\x32\x46.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXEndpointConfig\x12\x64\n\x12gce_cluster_config\x18\x07 \x01(\x0b\x32H.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXGceClusterConfig\x12k\n\x15initialization_action\x18\x08 \x03(\x0b\x32L.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXInitializationAction\x12\x61\n\x10lifecycle_config\x18\t \x01(\x0b\x32G.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXLifecycleConfig\x12[\n\rmaster_config\x18\n \x01(\x0b\x32\x44.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXMasterConfig\x12\x61\n\x10metastore_config\x18\x0b \x01(\x0b\x32G.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXMetastoreConfig\x12r\n\x19preemptible_worker_config\x18\x0c \x01(\x0b\x32O.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXPreemptibleWorkerConfig\x12_\n\x0fsecurity_config\x18\r \x01(\x0b\x32\x46.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXSecurityConfig\x12_\n\x0fsoftware_config\x18\x0e \x01(\x0b\x32\x46.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXSoftwareConfig\x12[\n\rworker_config\x18\x0f \x01(\x0b\x32\x44.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfigXWorkerConfig\"J\n\x18\x44\x61taprocClusterXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"r\nLDataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfigXMetastoreConfig\x12\"\n\x1a\x64\x61taproc_metastore_service\x18\x01 \x01(\t\"q\nUDataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfigXSparkHistoryServerConfig\x12\x18\n\x10\x64\x61taproc_cluster\x18\x01 \x01(\t\"\xd8\x02\n<DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfig\x12\x80\x01\n\x10metastore_config\x18\x01 \x01(\x0b\x32\x66.oak9.tython.gcp.dataproc.DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfigXMetastoreConfig\x12\x94\x01\n\x1bspark_history_server_config\x18\x02 \x01(\x0b\x32o.oak9.tython.gcp.dataproc.DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfigXSparkHistoryServerConfig\"\xa9\x01\nwDataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfigXAutoscaling\x12\x16\n\x0emax_node_count\x18\x01 \x01(\x01\x12\x16\n\x0emin_node_count\x18\x02 \x01(\x01\"\xe0\x01\nrDataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfigXConfig\x12\x17\n\x0flocal_ssd_count\x18\x01 \x01(\x01\x12\x14\n\x0cmachine_type\x18\x02 \x01(\t\x12\x18\n\x10min_cpu_platform\x18\x03 \x01(\t\x12\x13\n\x0bpreemptible\x18\x04 \x01(\x08\x12\x0c\n\x04spot\x18\x05 \x01(\x08\"\xca\x03\nkDataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfig\x12\x11\n\tlocations\x18\x01 \x03(\t\x12\xa7\x01\n\x0b\x61utoscaling\x18\x02 \x01(\x0b\x32\x91\x01.oak9.tython.gcp.dataproc.DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfigXAutoscaling\x12\x9d\x01\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x8c\x01.oak9.tython.gcp.dataproc.DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfigXConfig\"\xa3\x02\n\\DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTarget\x12\x11\n\tnode_pool\x18\x01 \x01(\t\x12\r\n\x05roles\x18\x02 \x03(\t\x12\xa0\x01\n\x10node_pool_config\x18\x03 \x01(\x0b\x32\x85\x01.oak9.tython.gcp.dataproc.DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfig\"\xfe\x01\nMDataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfig\x12\x1a\n\x12gke_cluster_target\x18\x01 \x01(\t\x12\x90\x01\n\x10node_pool_target\x18\x02 \x03(\x0b\x32v.oak9.tython.gcp.dataproc.DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTarget\"\xfd\x03\nUDataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXKubernetesSoftwareConfig\x12\xa1\x01\n\x11\x63omponent_version\x18\x01 \x03(\x0b\x32\x85\x01.oak9.tython.gcp.dataproc.DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXKubernetesSoftwareConfig.ComponentVersionEntry\x12\x93\x01\n\nproperties\x18\x02 \x03(\x0b\x32\x7f.oak9.tython.gcp.dataproc.DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXKubernetesSoftwareConfig.PropertiesEntry\x1a\x37\n\x15\x43omponentVersionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf8\x02\n<DataprocClusterXVirtualClusterConfigXKubernetesClusterConfig\x12\x1c\n\x14kubernetes_namespace\x18\x01 \x01(\t\x12\x83\x01\n\x12gke_cluster_config\x18\x02 \x01(\x0b\x32g.oak9.tython.gcp.dataproc.DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfig\x12\x93\x01\n\x1akubernetes_software_config\x18\x03 \x01(\x0b\x32o.oak9.tython.gcp.dataproc.DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXKubernetesSoftwareConfig\"\xb4\x02\n$DataprocClusterXVirtualClusterConfig\x12\x16\n\x0estaging_bucket\x18\x01 \x01(\t\x12y\n\x19\x61uxiliary_services_config\x18\x02 \x01(\x0b\x32V.oak9.tython.gcp.dataproc.DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfig\x12y\n\x19kubernetes_cluster_config\x18\x03 \x01(\x0b\x32V.oak9.tython.gcp.dataproc.DataprocClusterXVirtualClusterConfigXKubernetesClusterConfig\"\x99\x04\n\x0f\x44\x61taprocCluster\x12%\n\x1dgraceful_decommission_timeout\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x45\n\x06labels\x18\x03 \x03(\x0b\x32\x35.oak9.tython.gcp.dataproc.DataprocCluster.LabelsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12O\n\x0e\x63luster_config\x18\x07 \x01(\x0b\x32\x37.oak9.tython.gcp.dataproc.DataprocClusterXClusterConfig\x12\x44\n\x08timeouts\x18\x08 \x01(\x0b\x32\x32.oak9.tython.gcp.dataproc.DataprocClusterXTimeouts\x12^\n\x16virtual_cluster_config\x18\t \x01(\x0b\x32>.oak9.tython.gcp.dataproc.DataprocClusterXVirtualClusterConfig\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n#DataprocClusterIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x91\x02\n\x19\x44\x61taprocClusterIamBinding\x12\x0f\n\x07\x63luster\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12P\n\tcondition\x18\x08 \x01(\x0b\x32=.oak9.tython.gcp.dataproc.DataprocClusterIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\\\n\"DataprocClusterIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8e\x02\n\x18\x44\x61taprocClusterIamMember\x12\x0f\n\x07\x63luster\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12O\n\tcondition\x18\x08 \x01(\x0b\x32<.oak9.tython.gcp.dataproc.DataprocClusterIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb4\x01\n\x18\x44\x61taprocClusterIamPolicy\x12\x0f\n\x07\x63luster\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd2\x01\n&DataprocJobXHadoopConfigXLoggingConfig\x12p\n\x11\x64river_log_levels\x18\x01 \x03(\x0b\x32U.oak9.tython.gcp.dataproc.DataprocJobXHadoopConfigXLoggingConfig.DriverLogLevelsEntry\x1a\x36\n\x14\x44riverLogLevelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfc\x02\n\x18\x44\x61taprocJobXHadoopConfig\x12\x14\n\x0c\x61rchive_uris\x18\x01 \x03(\t\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x11\n\tfile_uris\x18\x03 \x03(\t\x12\x15\n\rjar_file_uris\x18\x04 \x03(\t\x12\x12\n\nmain_class\x18\x05 \x01(\t\x12\x19\n\x11main_jar_file_uri\x18\x06 \x01(\t\x12V\n\nproperties\x18\x07 \x03(\x0b\x32\x42.oak9.tython.gcp.dataproc.DataprocJobXHadoopConfig.PropertiesEntry\x12X\n\x0elogging_config\x18\x08 \x01(\x0b\x32@.oak9.tython.gcp.dataproc.DataprocJobXHadoopConfigXLoggingConfig\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x03\n\x16\x44\x61taprocJobXHiveConfig\x12\x1b\n\x13\x63ontinue_on_failure\x18\x01 \x01(\x08\x12\x15\n\rjar_file_uris\x18\x02 \x03(\t\x12T\n\nproperties\x18\x03 \x03(\x0b\x32@.oak9.tython.gcp.dataproc.DataprocJobXHiveConfig.PropertiesEntry\x12\x16\n\x0equery_file_uri\x18\x04 \x01(\t\x12\x12\n\nquery_list\x18\x05 \x03(\t\x12_\n\x10script_variables\x18\x06 \x03(\x0b\x32\x45.oak9.tython.gcp.dataproc.DataprocJobXHiveConfig.ScriptVariablesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14ScriptVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcc\x01\n#DataprocJobXPigConfigXLoggingConfig\x12m\n\x11\x64river_log_levels\x18\x01 \x03(\x0b\x32R.oak9.tython.gcp.dataproc.DataprocJobXPigConfigXLoggingConfig.DriverLogLevelsEntry\x1a\x36\n\x14\x44riverLogLevelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xee\x03\n\x15\x44\x61taprocJobXPigConfig\x12\x1b\n\x13\x63ontinue_on_failure\x18\x01 \x01(\x08\x12\x15\n\rjar_file_uris\x18\x02 \x03(\t\x12S\n\nproperties\x18\x03 \x03(\x0b\x32?.oak9.tython.gcp.dataproc.DataprocJobXPigConfig.PropertiesEntry\x12\x16\n\x0equery_file_uri\x18\x04 \x01(\t\x12\x12\n\nquery_list\x18\x05 \x03(\t\x12^\n\x10script_variables\x18\x06 \x03(\x0b\x32\x44.oak9.tython.gcp.dataproc.DataprocJobXPigConfig.ScriptVariablesEntry\x12U\n\x0elogging_config\x18\x07 \x01(\x0b\x32=.oak9.tython.gcp.dataproc.DataprocJobXPigConfigXLoggingConfig\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14ScriptVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"C\n\x15\x44\x61taprocJobXPlacement\x12\x14\n\x0c\x63luster_name\x18\x01 \x01(\t\x12\x14\n\x0c\x63luster_uuid\x18\x02 \x01(\t\"\xd2\x01\n&DataprocJobXPrestoConfigXLoggingConfig\x12p\n\x11\x64river_log_levels\x18\x01 \x03(\x0b\x32U.oak9.tython.gcp.dataproc.DataprocJobXPrestoConfigXLoggingConfig.DriverLogLevelsEntry\x1a\x36\n\x14\x44riverLogLevelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf4\x02\n\x18\x44\x61taprocJobXPrestoConfig\x12\x13\n\x0b\x63lient_tags\x18\x01 \x03(\t\x12\x1b\n\x13\x63ontinue_on_failure\x18\x02 \x01(\x08\x12\x15\n\routput_format\x18\x03 \x01(\t\x12V\n\nproperties\x18\x04 \x03(\x0b\x32\x42.oak9.tython.gcp.dataproc.DataprocJobXPrestoConfig.PropertiesEntry\x12\x16\n\x0equery_file_uri\x18\x05 \x01(\t\x12\x12\n\nquery_list\x18\x06 \x03(\t\x12X\n\x0elogging_config\x18\x07 \x01(\x0b\x32@.oak9.tython.gcp.dataproc.DataprocJobXPrestoConfigXLoggingConfig\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd4\x01\n\'DataprocJobXPysparkConfigXLoggingConfig\x12q\n\x11\x64river_log_levels\x18\x01 \x03(\x0b\x32V.oak9.tython.gcp.dataproc.DataprocJobXPysparkConfigXLoggingConfig.DriverLogLevelsEntry\x1a\x36\n\x14\x44riverLogLevelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x03\n\x19\x44\x61taprocJobXPysparkConfig\x12\x14\n\x0c\x61rchive_uris\x18\x01 \x03(\t\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x11\n\tfile_uris\x18\x03 \x03(\t\x12\x15\n\rjar_file_uris\x18\x04 \x03(\t\x12\x1c\n\x14main_python_file_uri\x18\x05 \x01(\t\x12W\n\nproperties\x18\x06 \x03(\x0b\x32\x43.oak9.tython.gcp.dataproc.DataprocJobXPysparkConfig.PropertiesEntry\x12\x18\n\x10python_file_uris\x18\x07 \x03(\t\x12Y\n\x0elogging_config\x18\x08 \x01(\x0b\x32\x41.oak9.tython.gcp.dataproc.DataprocJobXPysparkConfigXLoggingConfig\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x15\x44\x61taprocJobXReference\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"S\n\x16\x44\x61taprocJobXScheduling\x12\x1d\n\x15max_failures_per_hour\x18\x01 \x01(\x01\x12\x1a\n\x12max_failures_total\x18\x02 \x01(\x01\"\xd0\x01\n%DataprocJobXSparkConfigXLoggingConfig\x12o\n\x11\x64river_log_levels\x18\x01 \x03(\x0b\x32T.oak9.tython.gcp.dataproc.DataprocJobXSparkConfigXLoggingConfig.DriverLogLevelsEntry\x1a\x36\n\x14\x44riverLogLevelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf9\x02\n\x17\x44\x61taprocJobXSparkConfig\x12\x14\n\x0c\x61rchive_uris\x18\x01 \x03(\t\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x11\n\tfile_uris\x18\x03 \x03(\t\x12\x15\n\rjar_file_uris\x18\x04 \x03(\t\x12\x12\n\nmain_class\x18\x05 \x01(\t\x12\x19\n\x11main_jar_file_uri\x18\x06 \x01(\t\x12U\n\nproperties\x18\x07 \x03(\x0b\x32\x41.oak9.tython.gcp.dataproc.DataprocJobXSparkConfig.PropertiesEntry\x12W\n\x0elogging_config\x18\x08 \x01(\x0b\x32?.oak9.tython.gcp.dataproc.DataprocJobXSparkConfigXLoggingConfig\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd6\x01\n(DataprocJobXSparksqlConfigXLoggingConfig\x12r\n\x11\x64river_log_levels\x18\x01 \x03(\x0b\x32W.oak9.tython.gcp.dataproc.DataprocJobXSparksqlConfigXLoggingConfig.DriverLogLevelsEntry\x1a\x36\n\x14\x44riverLogLevelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe5\x03\n\x1a\x44\x61taprocJobXSparksqlConfig\x12\x15\n\rjar_file_uris\x18\x01 \x03(\t\x12X\n\nproperties\x18\x02 \x03(\x0b\x32\x44.oak9.tython.gcp.dataproc.DataprocJobXSparksqlConfig.PropertiesEntry\x12\x16\n\x0equery_file_uri\x18\x03 \x01(\t\x12\x12\n\nquery_list\x18\x04 \x03(\t\x12\x63\n\x10script_variables\x18\x05 \x03(\x0b\x32I.oak9.tython.gcp.dataproc.DataprocJobXSparksqlConfig.ScriptVariablesEntry\x12Z\n\x0elogging_config\x18\x06 \x01(\x0b\x32\x42.oak9.tython.gcp.dataproc.DataprocJobXSparksqlConfigXLoggingConfig\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14ScriptVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n\x14\x44\x61taprocJobXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xcb\t\n\x0b\x44\x61taprocJob\x12!\n\x19\x64river_controls_files_uri\x18\x01 \x01(\t\x12\"\n\x1a\x64river_output_resource_uri\x18\x02 \x01(\t\x12\x14\n\x0c\x66orce_delete\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12\x41\n\x06labels\x18\x05 \x03(\x0b\x32\x31.oak9.tython.gcp.dataproc.DataprocJob.LabelsEntry\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0e\n\x06region\x18\x07 \x01(\t\x12\x41\n\x06status\x18\x08 \x03(\x0b\x32\x31.oak9.tython.gcp.dataproc.DataprocJob.StatusEntry\x12I\n\rhadoop_config\x18\t \x01(\x0b\x32\x32.oak9.tython.gcp.dataproc.DataprocJobXHadoopConfig\x12\x45\n\x0bhive_config\x18\n \x01(\x0b\x32\x30.oak9.tython.gcp.dataproc.DataprocJobXHiveConfig\x12\x43\n\npig_config\x18\x0b \x01(\x0b\x32/.oak9.tython.gcp.dataproc.DataprocJobXPigConfig\x12\x42\n\tplacement\x18\x0c \x01(\x0b\x32/.oak9.tython.gcp.dataproc.DataprocJobXPlacement\x12I\n\rpresto_config\x18\r \x01(\x0b\x32\x32.oak9.tython.gcp.dataproc.DataprocJobXPrestoConfig\x12K\n\x0epyspark_config\x18\x0e \x01(\x0b\x32\x33.oak9.tython.gcp.dataproc.DataprocJobXPysparkConfig\x12\x42\n\treference\x18\x0f \x01(\x0b\x32/.oak9.tython.gcp.dataproc.DataprocJobXReference\x12\x44\n\nscheduling\x18\x10 \x01(\x0b\x32\x30.oak9.tython.gcp.dataproc.DataprocJobXScheduling\x12G\n\x0cspark_config\x18\x11 \x01(\x0b\x32\x31.oak9.tython.gcp.dataproc.DataprocJobXSparkConfig\x12M\n\x0fsparksql_config\x18\x12 \x01(\x0b\x32\x34.oak9.tython.gcp.dataproc.DataprocJobXSparksqlConfig\x12@\n\x08timeouts\x18\x13 \x01(\x0b\x32..oak9.tython.gcp.dataproc.DataprocJobXTimeouts\x12\x37\n\rresource_info\x18\x14 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bStatusEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Y\n\x1f\x44\x61taprocJobIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x88\x02\n\x15\x44\x61taprocJobIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06job_id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12L\n\tcondition\x18\x08 \x01(\x0b\x32\x39.oak9.tython.gcp.dataproc.DataprocJobIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"X\n\x1e\x44\x61taprocJobIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x85\x02\n\x14\x44\x61taprocJobIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06job_id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12K\n\tcondition\x18\x08 \x01(\x0b\x32\x38.oak9.tython.gcp.dataproc.DataprocJobIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xaf\x01\n\x14\x44\x61taprocJobIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06job_id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"<\n)DataprocMetastoreServiceXEncryptionConfig\x12\x0f\n\x07kms_key\x18\x01 \x01(\t\"Z\nBDataprocMetastoreServiceXHiveMetastoreConfigXKerberosConfigXKeytab\x12\x14\n\x0c\x63loud_secret\x18\x01 \x01(\t\"\xdb\x01\n;DataprocMetastoreServiceXHiveMetastoreConfigXKerberosConfig\x12\x1b\n\x13krb5_config_gcs_uri\x18\x01 \x01(\t\x12\x11\n\tprincipal\x18\x02 \x01(\t\x12l\n\x06keytab\x18\x03 \x01(\x0b\x32\\.oak9.tython.gcp.dataproc.DataprocMetastoreServiceXHiveMetastoreConfigXKerberosConfigXKeytab\"\xde\x02\n,DataprocMetastoreServiceXHiveMetastoreConfig\x12u\n\x10\x63onfig_overrides\x18\x01 \x03(\x0b\x32[.oak9.tython.gcp.dataproc.DataprocMetastoreServiceXHiveMetastoreConfig.ConfigOverridesEntry\x12\x0f\n\x07version\x18\x02 \x01(\t\x12n\n\x0fkerberos_config\x18\x03 \x01(\x0b\x32U.oak9.tython.gcp.dataproc.DataprocMetastoreServiceXHiveMetastoreConfigXKerberosConfig\x1a\x36\n\x14\x43onfigOverridesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"V\n*DataprocMetastoreServiceXMaintenanceWindow\x12\x13\n\x0b\x64\x61y_of_week\x18\x01 \x01(\t\x12\x13\n\x0bhour_of_day\x18\x02 \x01(\x01\"S\n!DataprocMetastoreServiceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xdb\x06\n\x18\x44\x61taprocMetastoreService\x12\x18\n\x10\x61rtifact_gcs_uri\x18\x01 \x01(\t\x12\x15\n\rdatabase_type\x18\x02 \x01(\t\x12\x14\n\x0c\x65ndpoint_uri\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12N\n\x06labels\x18\x05 \x03(\x0b\x32>.oak9.tython.gcp.dataproc.DataprocMetastoreService.LabelsEntry\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07network\x18\x08 \x01(\t\x12\x0c\n\x04port\x18\t \x01(\x01\x12\x0f\n\x07project\x18\n \x01(\t\x12\x17\n\x0frelease_channel\x18\x0b \x01(\t\x12\x12\n\nservice_id\x18\x0c \x01(\t\x12\r\n\x05state\x18\r \x01(\t\x12\x15\n\rstate_message\x18\x0e \x01(\t\x12\x0c\n\x04tier\x18\x0f \x01(\t\x12\x0b\n\x03uid\x18\x10 \x01(\t\x12^\n\x11\x65ncryption_config\x18\x11 \x01(\x0b\x32\x43.oak9.tython.gcp.dataproc.DataprocMetastoreServiceXEncryptionConfig\x12\x65\n\x15hive_metastore_config\x18\x12 \x01(\x0b\x32\x46.oak9.tython.gcp.dataproc.DataprocMetastoreServiceXHiveMetastoreConfig\x12`\n\x12maintenance_window\x18\x13 \x01(\x0b\x32\x44.oak9.tython.gcp.dataproc.DataprocMetastoreServiceXMaintenanceWindow\x12M\n\x08timeouts\x18\x14 \x01(\x0b\x32;.oak9.tython.gcp.dataproc.DataprocMetastoreServiceXTimeouts\x12\x37\n\rresource_info\x18\x15 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n,DataprocMetastoreServiceIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xa8\x02\n\"DataprocMetastoreServiceIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x12\n\nservice_id\x18\x07 \x01(\t\x12Y\n\tcondition\x18\x08 \x01(\x0b\x32\x46.oak9.tython.gcp.dataproc.DataprocMetastoreServiceIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"e\n+DataprocMetastoreServiceIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xa5\x02\n!DataprocMetastoreServiceIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x12\n\nservice_id\x18\x07 \x01(\t\x12X\n\tcondition\x18\x08 \x01(\x0b\x32\x45.oak9.tython.gcp.dataproc.DataprocMetastoreServiceIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc2\x01\n!DataprocMetastoreServiceIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x12\n\nservice_id\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf0\x01\n5DataprocWorkflowTemplateXJobsXHadoopJobXLoggingConfig\x12\x7f\n\x11\x64river_log_levels\x18\x01 \x03(\x0b\x32\x64.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXHadoopJobXLoggingConfig.DriverLogLevelsEntry\x1a\x36\n\x14\x44riverLogLevelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa9\x03\n\'DataprocWorkflowTemplateXJobsXHadoopJob\x12\x14\n\x0c\x61rchive_uris\x18\x01 \x03(\t\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x11\n\tfile_uris\x18\x03 \x03(\t\x12\x15\n\rjar_file_uris\x18\x04 \x03(\t\x12\x12\n\nmain_class\x18\x05 \x01(\t\x12\x19\n\x11main_jar_file_uri\x18\x06 \x01(\t\x12\x65\n\nproperties\x18\x07 \x03(\x0b\x32Q.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXHadoopJob.PropertiesEntry\x12g\n\x0elogging_config\x18\x08 \x01(\x0b\x32O.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXHadoopJobXLoggingConfig\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"B\n/DataprocWorkflowTemplateXJobsXHiveJobXQueryList\x12\x0f\n\x07queries\x18\x01 \x03(\t\"\x92\x04\n%DataprocWorkflowTemplateXJobsXHiveJob\x12\x1b\n\x13\x63ontinue_on_failure\x18\x01 \x01(\x08\x12\x15\n\rjar_file_uris\x18\x02 \x03(\t\x12\x63\n\nproperties\x18\x03 \x03(\x0b\x32O.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXHiveJob.PropertiesEntry\x12\x16\n\x0equery_file_uri\x18\x04 \x01(\t\x12n\n\x10script_variables\x18\x05 \x03(\x0b\x32T.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXHiveJob.ScriptVariablesEntry\x12]\n\nquery_list\x18\x06 \x01(\x0b\x32I.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXHiveJobXQueryList\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14ScriptVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xea\x01\n2DataprocWorkflowTemplateXJobsXPigJobXLoggingConfig\x12|\n\x11\x64river_log_levels\x18\x01 \x03(\x0b\x32\x61.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXPigJobXLoggingConfig.DriverLogLevelsEntry\x1a\x36\n\x14\x44riverLogLevelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"A\n.DataprocWorkflowTemplateXJobsXPigJobXQueryList\x12\x0f\n\x07queries\x18\x01 \x03(\t\"\xf4\x04\n$DataprocWorkflowTemplateXJobsXPigJob\x12\x1b\n\x13\x63ontinue_on_failure\x18\x01 \x01(\x08\x12\x15\n\rjar_file_uris\x18\x02 \x03(\t\x12\x62\n\nproperties\x18\x03 \x03(\x0b\x32N.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXPigJob.PropertiesEntry\x12\x16\n\x0equery_file_uri\x18\x04 \x01(\t\x12m\n\x10script_variables\x18\x05 \x03(\x0b\x32S.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXPigJob.ScriptVariablesEntry\x12\x64\n\x0elogging_config\x18\x06 \x01(\x0b\x32L.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXPigJobXLoggingConfig\x12\\\n\nquery_list\x18\x07 \x01(\x0b\x32H.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXPigJobXQueryList\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14ScriptVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf0\x01\n5DataprocWorkflowTemplateXJobsXPrestoJobXLoggingConfig\x12\x7f\n\x11\x64river_log_levels\x18\x01 \x03(\x0b\x32\x64.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXPrestoJobXLoggingConfig.DriverLogLevelsEntry\x1a\x36\n\x14\x44riverLogLevelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"D\n1DataprocWorkflowTemplateXJobsXPrestoJobXQueryList\x12\x0f\n\x07queries\x18\x01 \x03(\t\"\xee\x03\n\'DataprocWorkflowTemplateXJobsXPrestoJob\x12\x13\n\x0b\x63lient_tags\x18\x01 \x03(\t\x12\x1b\n\x13\x63ontinue_on_failure\x18\x02 \x01(\x08\x12\x15\n\routput_format\x18\x03 \x01(\t\x12\x65\n\nproperties\x18\x04 \x03(\x0b\x32Q.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXPrestoJob.PropertiesEntry\x12\x16\n\x0equery_file_uri\x18\x05 \x01(\t\x12g\n\x0elogging_config\x18\x06 \x01(\x0b\x32O.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXPrestoJobXLoggingConfig\x12_\n\nquery_list\x18\x07 \x01(\x0b\x32K.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXPrestoJobXQueryList\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf3\x01\n6DataprocWorkflowTemplateXJobsXPysparkJobXLoggingConfig\x12\x80\x01\n\x11\x64river_log_levels\x18\x01 \x03(\x0b\x32\x65.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXPysparkJobXLoggingConfig.DriverLogLevelsEntry\x1a\x36\n\x14\x44riverLogLevelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb5\x03\n(DataprocWorkflowTemplateXJobsXPysparkJob\x12\x14\n\x0c\x61rchive_uris\x18\x01 \x03(\t\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x11\n\tfile_uris\x18\x03 \x03(\t\x12\x15\n\rjar_file_uris\x18\x04 \x03(\t\x12\x1c\n\x14main_python_file_uri\x18\x05 \x01(\t\x12\x66\n\nproperties\x18\x06 \x03(\x0b\x32R.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXPysparkJob.PropertiesEntry\x12\x18\n\x10python_file_uris\x18\x07 \x03(\t\x12h\n\x0elogging_config\x18\x08 \x01(\x0b\x32P.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXPysparkJobXLoggingConfig\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n(DataprocWorkflowTemplateXJobsXScheduling\x12\x1d\n\x15max_failures_per_hour\x18\x01 \x01(\x01\x12\x1a\n\x12max_failures_total\x18\x02 \x01(\x01\"\xee\x01\n4DataprocWorkflowTemplateXJobsXSparkJobXLoggingConfig\x12~\n\x11\x64river_log_levels\x18\x01 \x03(\x0b\x32\x63.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXSparkJobXLoggingConfig.DriverLogLevelsEntry\x1a\x36\n\x14\x44riverLogLevelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa6\x03\n&DataprocWorkflowTemplateXJobsXSparkJob\x12\x14\n\x0c\x61rchive_uris\x18\x01 \x03(\t\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x11\n\tfile_uris\x18\x03 \x03(\t\x12\x15\n\rjar_file_uris\x18\x04 \x03(\t\x12\x12\n\nmain_class\x18\x05 \x01(\t\x12\x19\n\x11main_jar_file_uri\x18\x06 \x01(\t\x12\x64\n\nproperties\x18\x07 \x03(\x0b\x32P.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXSparkJob.PropertiesEntry\x12\x66\n\x0elogging_config\x18\x08 \x01(\x0b\x32N.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXSparkJobXLoggingConfig\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf0\x01\n5DataprocWorkflowTemplateXJobsXSparkRJobXLoggingConfig\x12\x7f\n\x11\x64river_log_levels\x18\x01 \x03(\x0b\x32\x64.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXSparkRJobXLoggingConfig.DriverLogLevelsEntry\x1a\x36\n\x14\x44riverLogLevelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfc\x02\n\'DataprocWorkflowTemplateXJobsXSparkRJob\x12\x14\n\x0c\x61rchive_uris\x18\x01 \x03(\t\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x11\n\tfile_uris\x18\x03 \x03(\t\x12\x17\n\x0fmain_r_file_uri\x18\x04 \x01(\t\x12\x65\n\nproperties\x18\x05 \x03(\x0b\x32Q.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXSparkRJob.PropertiesEntry\x12g\n\x0elogging_config\x18\x06 \x01(\x0b\x32O.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXSparkRJobXLoggingConfig\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf5\x01\n7DataprocWorkflowTemplateXJobsXSparkSqlJobXLoggingConfig\x12\x81\x01\n\x11\x64river_log_levels\x18\x01 \x03(\x0b\x32\x66.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXSparkSqlJobXLoggingConfig.DriverLogLevelsEntry\x1a\x36\n\x14\x44riverLogLevelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"F\n3DataprocWorkflowTemplateXJobsXSparkSqlJobXQueryList\x12\x0f\n\x07queries\x18\x01 \x03(\t\"\xf0\x04\n)DataprocWorkflowTemplateXJobsXSparkSqlJob\x12\x15\n\rjar_file_uris\x18\x01 \x03(\t\x12g\n\nproperties\x18\x02 \x03(\x0b\x32S.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXSparkSqlJob.PropertiesEntry\x12\x16\n\x0equery_file_uri\x18\x03 \x01(\t\x12r\n\x10script_variables\x18\x04 \x03(\x0b\x32X.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXSparkSqlJob.ScriptVariablesEntry\x12i\n\x0elogging_config\x18\x05 \x01(\x0b\x32Q.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXSparkSqlJobXLoggingConfig\x12\x61\n\nquery_list\x18\x06 \x01(\x0b\x32M.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXSparkSqlJobXQueryList\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14ScriptVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdf\x07\n\x1d\x44\x61taprocWorkflowTemplateXJobs\x12S\n\x06labels\x18\x01 \x03(\x0b\x32\x43.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobs.LabelsEntry\x12\x1d\n\x15prerequisite_step_ids\x18\x02 \x03(\t\x12\x0f\n\x07step_id\x18\x03 \x01(\t\x12U\n\nhadoop_job\x18\x04 \x01(\x0b\x32\x41.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXHadoopJob\x12Q\n\x08hive_job\x18\x05 \x01(\x0b\x32?.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXHiveJob\x12O\n\x07pig_job\x18\x06 \x01(\x0b\x32>.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXPigJob\x12U\n\npresto_job\x18\x07 \x01(\x0b\x32\x41.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXPrestoJob\x12W\n\x0bpyspark_job\x18\x08 \x01(\x0b\x32\x42.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXPysparkJob\x12V\n\nscheduling\x18\t \x01(\x0b\x32\x42.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXScheduling\x12S\n\tspark_job\x18\n \x01(\x0b\x32@.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXSparkJob\x12V\n\x0bspark_r_job\x18\x0b \x01(\x0b\x32\x41.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXSparkRJob\x12Z\n\rspark_sql_job\x18\x0c \x01(\x0b\x32\x43.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobsXSparkSqlJob\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"G\n4DataprocWorkflowTemplateXParametersXValidationXRegex\x12\x0f\n\x07regexes\x18\x01 \x03(\t\"G\n5DataprocWorkflowTemplateXParametersXValidationXValues\x12\x0e\n\x06values\x18\x01 \x03(\t\"\xf0\x01\n.DataprocWorkflowTemplateXParametersXValidation\x12]\n\x05regex\x18\x01 \x01(\x0b\x32N.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXParametersXValidationXRegex\x12_\n\x06values\x18\x02 \x01(\x0b\x32O.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXParametersXValidationXValues\"\xb6\x01\n#DataprocWorkflowTemplateXParameters\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06\x66ields\x18\x02 \x03(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\\\n\nvalidation\x18\x04 \x01(\x0b\x32H.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXParametersXValidation\"\xf1\x01\n2DataprocWorkflowTemplateXPlacementXClusterSelector\x12w\n\x0e\x63luster_labels\x18\x01 \x03(\x0b\x32_.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXClusterSelector.ClusterLabelsEntry\x12\x0c\n\x04zone\x18\x02 \x01(\t\x1a\x34\n\x12\x43lusterLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\\\nJDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXAutoscalingConfig\x12\x0e\n\x06policy\x18\x01 \x01(\t\"h\nIDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXEncryptionConfig\x12\x1b\n\x13gce_pd_kms_key_name\x18\x01 \x01(\t\"\xa3\x02\nGDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXEndpointConfig\x12\x1f\n\x17\x65nable_http_port_access\x18\x01 \x01(\x08\x12\x84\x01\n\nhttp_ports\x18\x02 \x03(\x0b\x32p.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXEndpointConfig.HttpPortsEntry\x1a\x30\n\x0eHttpPortsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"q\n[DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfigXNodeGroupAffinity\x12\x12\n\nnode_group\x18\x01 \x01(\t\"\x9e\x01\n]DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfigXReservationAffinity\x12 \n\x18\x63onsume_reservation_type\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\xe7\x05\nIDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfig\x12\x18\n\x10internal_ip_only\x18\x01 \x01(\x08\x12\x83\x01\n\x08metadata\x18\x02 \x03(\x0b\x32q.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfig.MetadataEntry\x12\x0f\n\x07network\x18\x03 \x01(\t\x12\"\n\x1aprivate_ipv6_google_access\x18\x04 \x01(\t\x12\x17\n\x0fservice_account\x18\x05 \x01(\t\x12\x1e\n\x16service_account_scopes\x18\x06 \x03(\t\x12\x12\n\nsubnetwork\x18\x07 \x01(\t\x12\x0c\n\x04tags\x18\x08 \x03(\t\x12\x0c\n\x04zone\x18\t \x01(\t\x12\x92\x01\n\x13node_group_affinity\x18\n \x01(\x0b\x32u.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfigXNodeGroupAffinity\x12\x95\x01\n\x14reservation_affinity\x18\x0b \x01(\x0b\x32w.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfigXReservationAffinity\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x84\x01\nNDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXInitializationActions\x12\x17\n\x0f\x65xecutable_file\x18\x01 \x01(\t\x12\x19\n\x11\x65xecution_timeout\x18\x02 \x01(\t\"\xaf\x01\nHDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXLifecycleConfig\x12\x18\n\x10\x61uto_delete_time\x18\x01 \x01(\t\x12\x17\n\x0f\x61uto_delete_ttl\x18\x02 \x01(\t\x12\x17\n\x0fidle_delete_ttl\x18\x03 \x01(\t\x12\x17\n\x0fidle_start_time\x18\x04 \x01(\t\"\x89\x01\nRDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfigXAccelerators\x12\x19\n\x11\x61\x63\x63\x65lerator_count\x18\x01 \x01(\x01\x12\x18\n\x10\x61\x63\x63\x65lerator_type\x18\x02 \x01(\t\"\x9d\x01\nPDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfigXDiskConfig\x12\x19\n\x11\x62oot_disk_size_gb\x18\x01 \x01(\x01\x12\x16\n\x0e\x62oot_disk_type\x18\x02 \x01(\t\x12\x16\n\x0enum_local_ssds\x18\x03 \x01(\x01\"\xbe\x05\nEDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfig\x12\r\n\x05image\x18\x01 \x01(\t\x12\x16\n\x0einstance_names\x18\x02 \x03(\t\x12\x16\n\x0eis_preemptible\x18\x03 \x01(\x08\x12\x14\n\x0cmachine_type\x18\x04 \x01(\t\x12\x95\x01\n\x14managed_group_config\x18\x05 \x03(\x0b\x32w.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfig.ManagedGroupConfigEntry\x12\x18\n\x10min_cpu_platform\x18\x06 \x01(\t\x12\x15\n\rnum_instances\x18\x07 \x01(\x01\x12\x16\n\x0epreemptibility\x18\x08 \x01(\t\x12\x82\x01\n\x0c\x61\x63\x63\x65lerators\x18\t \x03(\x0b\x32l.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfigXAccelerators\x12\x7f\n\x0b\x64isk_config\x18\n \x01(\x0b\x32j.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfigXDiskConfig\x1a\x39\n\x17ManagedGroupConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x01\n[DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfigXAccelerators\x12\x19\n\x11\x61\x63\x63\x65lerator_count\x18\x01 \x01(\x01\x12\x18\n\x10\x61\x63\x63\x65lerator_type\x18\x02 \x01(\t\"\xa6\x01\nYDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfigXDiskConfig\x12\x19\n\x11\x62oot_disk_size_gb\x18\x01 \x01(\x01\x12\x16\n\x0e\x62oot_disk_type\x18\x02 \x01(\t\x12\x16\n\x0enum_local_ssds\x18\x03 \x01(\x01\"\xe4\x05\nNDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfig\x12\r\n\x05image\x18\x01 \x01(\t\x12\x16\n\x0einstance_names\x18\x02 \x03(\t\x12\x16\n\x0eis_preemptible\x18\x03 \x01(\x08\x12\x14\n\x0cmachine_type\x18\x04 \x01(\t\x12\x9f\x01\n\x14managed_group_config\x18\x05 \x03(\x0b\x32\x80\x01.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfig.ManagedGroupConfigEntry\x12\x18\n\x10min_cpu_platform\x18\x06 \x01(\t\x12\x15\n\rnum_instances\x18\x07 \x01(\x01\x12\x16\n\x0epreemptibility\x18\x08 \x01(\t\x12\x8b\x01\n\x0c\x61\x63\x63\x65lerators\x18\t \x03(\x0b\x32u.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfigXAccelerators\x12\x88\x01\n\x0b\x64isk_config\x18\n \x01(\x0b\x32s.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfigXDiskConfig\x1a\x39\n\x17ManagedGroupConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe9\x03\nVDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecurityConfigXKerberosConfig\x12&\n\x1e\x63ross_realm_trust_admin_server\x18\x01 \x01(\t\x12\x1d\n\x15\x63ross_realm_trust_kdc\x18\x02 \x01(\t\x12\x1f\n\x17\x63ross_realm_trust_realm\x18\x03 \x01(\t\x12)\n!cross_realm_trust_shared_password\x18\x04 \x01(\t\x12\x17\n\x0f\x65nable_kerberos\x18\x05 \x01(\x08\x12\x12\n\nkdc_db_key\x18\x06 \x01(\t\x12\x14\n\x0ckey_password\x18\x07 \x01(\t\x12\x10\n\x08keystore\x18\x08 \x01(\t\x12\x19\n\x11keystore_password\x18\t \x01(\t\x12\x0f\n\x07kms_key\x18\n \x01(\t\x12\r\n\x05realm\x18\x0b \x01(\t\x12\x1f\n\x17root_principal_password\x18\x0c \x01(\t\x12\x1a\n\x12tgt_lifetime_hours\x18\r \x01(\x01\x12\x12\n\ntruststore\x18\x0e \x01(\t\x12\x1b\n\x13truststore_password\x18\x0f \x01(\t\"\xd5\x01\nGDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecurityConfig\x12\x89\x01\n\x0fkerberos_config\x18\x01 \x01(\x0b\x32p.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecurityConfigXKerberosConfig\"\xb8\x02\nGDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSoftwareConfig\x12\x15\n\rimage_version\x18\x01 \x01(\t\x12\x1b\n\x13optional_components\x18\x02 \x03(\t\x12\x85\x01\n\nproperties\x18\x03 \x03(\x0b\x32q.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSoftwareConfig.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x89\x01\nRDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfigXAccelerators\x12\x19\n\x11\x61\x63\x63\x65lerator_count\x18\x01 \x01(\x01\x12\x18\n\x10\x61\x63\x63\x65lerator_type\x18\x02 \x01(\t\"\x9d\x01\nPDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfigXDiskConfig\x12\x19\n\x11\x62oot_disk_size_gb\x18\x01 \x01(\x01\x12\x16\n\x0e\x62oot_disk_type\x18\x02 \x01(\t\x12\x16\n\x0enum_local_ssds\x18\x03 \x01(\x01\"\xbe\x05\nEDataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfig\x12\r\n\x05image\x18\x01 \x01(\t\x12\x16\n\x0einstance_names\x18\x02 \x03(\t\x12\x16\n\x0eis_preemptible\x18\x03 \x01(\x08\x12\x14\n\x0cmachine_type\x18\x04 \x01(\t\x12\x95\x01\n\x14managed_group_config\x18\x05 \x03(\x0b\x32w.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfig.ManagedGroupConfigEntry\x12\x18\n\x10min_cpu_platform\x18\x06 \x01(\t\x12\x15\n\rnum_instances\x18\x07 \x01(\x01\x12\x16\n\x0epreemptibility\x18\x08 \x01(\t\x12\x82\x01\n\x0c\x61\x63\x63\x65lerators\x18\t \x03(\x0b\x32l.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfigXAccelerators\x12\x7f\n\x0b\x64isk_config\x18\n \x01(\x0b\x32j.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfigXDiskConfig\x1a\x39\n\x17ManagedGroupConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe4\x0b\n8DataprocWorkflowTemplateXPlacementXManagedClusterXConfig\x12\x16\n\x0estaging_bucket\x18\x01 \x01(\t\x12\x13\n\x0btemp_bucket\x18\x02 \x01(\t\x12\x80\x01\n\x12\x61utoscaling_config\x18\x03 \x01(\x0b\x32\x64.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXAutoscalingConfig\x12~\n\x11\x65ncryption_config\x18\x04 \x01(\x0b\x32\x63.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXEncryptionConfig\x12z\n\x0f\x65ndpoint_config\x18\x05 \x01(\x0b\x32\x61.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXEndpointConfig\x12\x7f\n\x12gce_cluster_config\x18\x06 \x01(\x0b\x32\x63.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfig\x12\x88\x01\n\x16initialization_actions\x18\x07 \x03(\x0b\x32h.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXInitializationActions\x12|\n\x10lifecycle_config\x18\x08 \x01(\x0b\x32\x62.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXLifecycleConfig\x12v\n\rmaster_config\x18\t \x01(\x0b\x32_.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfig\x12\x89\x01\n\x17secondary_worker_config\x18\n \x01(\x0b\x32h.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfig\x12z\n\x0fsecurity_config\x18\x0b \x01(\x0b\x32\x61.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecurityConfig\x12z\n\x0fsoftware_config\x18\x0c \x01(\x0b\x32\x61.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSoftwareConfig\x12v\n\rworker_config\x18\r \x01(\x0b\x32_.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfig\"\xc5\x02\n1DataprocWorkflowTemplateXPlacementXManagedCluster\x12\x14\n\x0c\x63luster_name\x18\x01 \x01(\t\x12g\n\x06labels\x18\x02 \x03(\x0b\x32W.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedCluster.LabelsEntry\x12\x62\n\x06\x63onfig\x18\x03 \x01(\x0b\x32R.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedClusterXConfig\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf2\x01\n\"DataprocWorkflowTemplateXPlacement\x12\x66\n\x10\x63luster_selector\x18\x01 \x01(\x0b\x32L.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXClusterSelector\x12\x64\n\x0fmanaged_cluster\x18\x02 \x01(\x0b\x32K.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacementXManagedCluster\"C\n!DataprocWorkflowTemplateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x99\x05\n\x18\x44\x61taprocWorkflowTemplate\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61g_timeout\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12N\n\x06labels\x18\x04 \x03(\x0b\x32>.oak9.tython.gcp.dataproc.DataprocWorkflowTemplate.LabelsEntry\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x13\n\x0bupdate_time\x18\x08 \x01(\t\x12\x0f\n\x07version\x18\t \x01(\x01\x12\x45\n\x04jobs\x18\n \x03(\x0b\x32\x37.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXJobs\x12Q\n\nparameters\x18\x0b \x03(\x0b\x32=.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXParameters\x12O\n\tplacement\x18\x0c \x01(\x0b\x32<.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXPlacement\x12M\n\x08timeouts\x18\r \x01(\x0b\x32;.oak9.tython.gcp.dataproc.DataprocWorkflowTemplateXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_dataproc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATAPROCCLUSTERXCLUSTERCONFIGXENDPOINTCONFIG_HTTPPORTSENTRY._options = None
  _DATAPROCCLUSTERXCLUSTERCONFIGXENDPOINTCONFIG_HTTPPORTSENTRY._serialized_options = b'8\001'
  _DATAPROCCLUSTERXCLUSTERCONFIGXGCECLUSTERCONFIG_METADATAENTRY._options = None
  _DATAPROCCLUSTERXCLUSTERCONFIGXGCECLUSTERCONFIG_METADATAENTRY._serialized_options = b'8\001'
  _DATAPROCCLUSTERXCLUSTERCONFIGXSOFTWARECONFIG_OVERRIDEPROPERTIESENTRY._options = None
  _DATAPROCCLUSTERXCLUSTERCONFIGXSOFTWARECONFIG_OVERRIDEPROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCCLUSTERXCLUSTERCONFIGXSOFTWARECONFIG_PROPERTIESENTRY._options = None
  _DATAPROCCLUSTERXCLUSTERCONFIGXSOFTWARECONFIG_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXKUBERNETESSOFTWARECONFIG_COMPONENTVERSIONENTRY._options = None
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXKUBERNETESSOFTWARECONFIG_COMPONENTVERSIONENTRY._serialized_options = b'8\001'
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXKUBERNETESSOFTWARECONFIG_PROPERTIESENTRY._options = None
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXKUBERNETESSOFTWARECONFIG_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCCLUSTER_LABELSENTRY._options = None
  _DATAPROCCLUSTER_LABELSENTRY._serialized_options = b'8\001'
  _DATAPROCJOBXHADOOPCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._options = None
  _DATAPROCJOBXHADOOPCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_options = b'8\001'
  _DATAPROCJOBXHADOOPCONFIG_PROPERTIESENTRY._options = None
  _DATAPROCJOBXHADOOPCONFIG_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCJOBXHIVECONFIG_PROPERTIESENTRY._options = None
  _DATAPROCJOBXHIVECONFIG_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCJOBXHIVECONFIG_SCRIPTVARIABLESENTRY._options = None
  _DATAPROCJOBXHIVECONFIG_SCRIPTVARIABLESENTRY._serialized_options = b'8\001'
  _DATAPROCJOBXPIGCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._options = None
  _DATAPROCJOBXPIGCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_options = b'8\001'
  _DATAPROCJOBXPIGCONFIG_PROPERTIESENTRY._options = None
  _DATAPROCJOBXPIGCONFIG_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCJOBXPIGCONFIG_SCRIPTVARIABLESENTRY._options = None
  _DATAPROCJOBXPIGCONFIG_SCRIPTVARIABLESENTRY._serialized_options = b'8\001'
  _DATAPROCJOBXPRESTOCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._options = None
  _DATAPROCJOBXPRESTOCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_options = b'8\001'
  _DATAPROCJOBXPRESTOCONFIG_PROPERTIESENTRY._options = None
  _DATAPROCJOBXPRESTOCONFIG_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCJOBXPYSPARKCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._options = None
  _DATAPROCJOBXPYSPARKCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_options = b'8\001'
  _DATAPROCJOBXPYSPARKCONFIG_PROPERTIESENTRY._options = None
  _DATAPROCJOBXPYSPARKCONFIG_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCJOBXSPARKCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._options = None
  _DATAPROCJOBXSPARKCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_options = b'8\001'
  _DATAPROCJOBXSPARKCONFIG_PROPERTIESENTRY._options = None
  _DATAPROCJOBXSPARKCONFIG_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCJOBXSPARKSQLCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._options = None
  _DATAPROCJOBXSPARKSQLCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_options = b'8\001'
  _DATAPROCJOBXSPARKSQLCONFIG_PROPERTIESENTRY._options = None
  _DATAPROCJOBXSPARKSQLCONFIG_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCJOBXSPARKSQLCONFIG_SCRIPTVARIABLESENTRY._options = None
  _DATAPROCJOBXSPARKSQLCONFIG_SCRIPTVARIABLESENTRY._serialized_options = b'8\001'
  _DATAPROCJOB_LABELSENTRY._options = None
  _DATAPROCJOB_LABELSENTRY._serialized_options = b'8\001'
  _DATAPROCJOB_STATUSENTRY._options = None
  _DATAPROCJOB_STATUSENTRY._serialized_options = b'8\001'
  _DATAPROCMETASTORESERVICEXHIVEMETASTORECONFIG_CONFIGOVERRIDESENTRY._options = None
  _DATAPROCMETASTORESERVICEXHIVEMETASTORECONFIG_CONFIGOVERRIDESENTRY._serialized_options = b'8\001'
  _DATAPROCMETASTORESERVICE_LABELSENTRY._options = None
  _DATAPROCMETASTORESERVICE_LABELSENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHADOOPJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHADOOPJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHADOOPJOB_PROPERTIESENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHADOOPJOB_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHIVEJOB_PROPERTIESENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHIVEJOB_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHIVEJOB_SCRIPTVARIABLESENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHIVEJOB_SCRIPTVARIABLESENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOB_PROPERTIESENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOB_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOB_SCRIPTVARIABLESENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOB_SCRIPTVARIABLESENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPRESTOJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPRESTOJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPRESTOJOB_PROPERTIESENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPRESTOJOB_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPYSPARKJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPYSPARKJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPYSPARKJOB_PROPERTIESENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPYSPARKJOB_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKJOB_PROPERTIESENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKJOB_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKRJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKRJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKRJOB_PROPERTIESENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKRJOB_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOB_PROPERTIESENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOB_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOB_SCRIPTVARIABLESENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOB_SCRIPTVARIABLESENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXJOBS_LABELSENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXJOBS_LABELSENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXCLUSTERSELECTOR_CLUSTERLABELSENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXCLUSTERSELECTOR_CLUSTERLABELSENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXENDPOINTCONFIG_HTTPPORTSENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXENDPOINTCONFIG_HTTPPORTSENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXGCECLUSTERCONFIG_METADATAENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXGCECLUSTERCONFIG_METADATAENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXMASTERCONFIG_MANAGEDGROUPCONFIGENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXMASTERCONFIG_MANAGEDGROUPCONFIGENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSECONDARYWORKERCONFIG_MANAGEDGROUPCONFIGENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSECONDARYWORKERCONFIG_MANAGEDGROUPCONFIGENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSOFTWARECONFIG_PROPERTIESENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSOFTWARECONFIG_PROPERTIESENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXWORKERCONFIG_MANAGEDGROUPCONFIGENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXWORKERCONFIG_MANAGEDGROUPCONFIGENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTER_LABELSENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTER_LABELSENTRY._serialized_options = b'8\001'
  _DATAPROCWORKFLOWTEMPLATE_LABELSENTRY._options = None
  _DATAPROCWORKFLOWTEMPLATE_LABELSENTRY._serialized_options = b'8\001'
  _DATAPROCAUTOSCALINGPOLICYXBASICALGORITHMXYARNCONFIG._serialized_start=74
  _DATAPROCAUTOSCALINGPOLICYXBASICALGORITHMXYARNCONFIG._serialized_end=296
  _DATAPROCAUTOSCALINGPOLICYXBASICALGORITHM._serialized_start=299
  _DATAPROCAUTOSCALINGPOLICYXBASICALGORITHM._serialized_end=466
  _DATAPROCAUTOSCALINGPOLICYXSECONDARYWORKERCONFIG._serialized_start=468
  _DATAPROCAUTOSCALINGPOLICYXSECONDARYWORKERCONFIG._serialized_end=579
  _DATAPROCAUTOSCALINGPOLICYXTIMEOUTS._serialized_start=581
  _DATAPROCAUTOSCALINGPOLICYXTIMEOUTS._serialized_end=665
  _DATAPROCAUTOSCALINGPOLICYXWORKERCONFIG._serialized_start=667
  _DATAPROCAUTOSCALINGPOLICYXWORKERCONFIG._serialized_end=769
  _DATAPROCAUTOSCALINGPOLICY._serialized_start=772
  _DATAPROCAUTOSCALINGPOLICY._serialized_end=1306
  _DATAPROCAUTOSCALINGPOLICYIAMBINDINGXCONDITION._serialized_start=1308
  _DATAPROCAUTOSCALINGPOLICYIAMBINDINGXCONDITION._serialized_end=1411
  _DATAPROCAUTOSCALINGPOLICYIAMBINDING._serialized_start=1414
  _DATAPROCAUTOSCALINGPOLICYIAMBINDING._serialized_end=1711
  _DATAPROCAUTOSCALINGPOLICYIAMMEMBERXCONDITION._serialized_start=1713
  _DATAPROCAUTOSCALINGPOLICYIAMMEMBERXCONDITION._serialized_end=1815
  _DATAPROCAUTOSCALINGPOLICYIAMMEMBER._serialized_start=1818
  _DATAPROCAUTOSCALINGPOLICYIAMMEMBER._serialized_end=2112
  _DATAPROCAUTOSCALINGPOLICYIAMPOLICY._serialized_start=2115
  _DATAPROCAUTOSCALINGPOLICYIAMPOLICY._serialized_end=2309
  _DATAPROCCLUSTERXCLUSTERCONFIGXAUTOSCALINGCONFIG._serialized_start=2311
  _DATAPROCCLUSTERXCLUSTERCONFIGXAUTOSCALINGCONFIG._serialized_end=2380
  _DATAPROCCLUSTERXCLUSTERCONFIGXENCRYPTIONCONFIG._serialized_start=2382
  _DATAPROCCLUSTERXCLUSTERCONFIGXENCRYPTIONCONFIG._serialized_end=2452
  _DATAPROCCLUSTERXCLUSTERCONFIGXENDPOINTCONFIG._serialized_start=2455
  _DATAPROCCLUSTERXCLUSTERCONFIGXENDPOINTCONFIG._serialized_end=2691
  _DATAPROCCLUSTERXCLUSTERCONFIGXENDPOINTCONFIG_HTTPPORTSENTRY._serialized_start=2643
  _DATAPROCCLUSTERXCLUSTERCONFIGXENDPOINTCONFIG_HTTPPORTSENTRY._serialized_end=2691
  _DATAPROCCLUSTERXCLUSTERCONFIGXGCECLUSTERCONFIGXSHIELDEDINSTANCECONFIG._serialized_start=2694
  _DATAPROCCLUSTERXCLUSTERCONFIGXGCECLUSTERCONFIGXSHIELDEDINSTANCECONFIG._serialized_end=2851
  _DATAPROCCLUSTERXCLUSTERCONFIGXGCECLUSTERCONFIG._serialized_start=2854
  _DATAPROCCLUSTERXCLUSTERCONFIGXGCECLUSTERCONFIG._serialized_end=3337
  _DATAPROCCLUSTERXCLUSTERCONFIGXGCECLUSTERCONFIG_METADATAENTRY._serialized_start=3290
  _DATAPROCCLUSTERXCLUSTERCONFIGXGCECLUSTERCONFIG_METADATAENTRY._serialized_end=3337
  _DATAPROCCLUSTERXCLUSTERCONFIGXINITIALIZATIONACTION._serialized_start=3339
  _DATAPROCCLUSTERXCLUSTERCONFIGXINITIALIZATIONACTION._serialized_end=3428
  _DATAPROCCLUSTERXCLUSTERCONFIGXLIFECYCLECONFIG._serialized_start=3430
  _DATAPROCCLUSTERXCLUSTERCONFIGXLIFECYCLECONFIG._serialized_end=3553
  _DATAPROCCLUSTERXCLUSTERCONFIGXMASTERCONFIGXACCELERATORS._serialized_start=3555
  _DATAPROCCLUSTERXCLUSTERCONFIGXMASTERCONFIGXACCELERATORS._serialized_end=3665
  _DATAPROCCLUSTERXCLUSTERCONFIGXMASTERCONFIGXDISKCONFIG._serialized_start=3668
  _DATAPROCCLUSTERXCLUSTERCONFIGXMASTERCONFIGXDISKCONFIG._serialized_end=3798
  _DATAPROCCLUSTERXCLUSTERCONFIGXMASTERCONFIG._serialized_start=3801
  _DATAPROCCLUSTERXCLUSTERCONFIGXMASTERCONFIG._serialized_end=4166
  _DATAPROCCLUSTERXCLUSTERCONFIGXMETASTORECONFIG._serialized_start=4168
  _DATAPROCCLUSTERXCLUSTERCONFIGXMETASTORECONFIG._serialized_end=4251
  _DATAPROCCLUSTERXCLUSTERCONFIGXPREEMPTIBLEWORKERCONFIGXDISKCONFIG._serialized_start=4254
  _DATAPROCCLUSTERXCLUSTERCONFIGXPREEMPTIBLEWORKERCONFIGXDISKCONFIG._serialized_end=4395
  _DATAPROCCLUSTERXCLUSTERCONFIGXPREEMPTIBLEWORKERCONFIG._serialized_start=4398
  _DATAPROCCLUSTERXCLUSTERCONFIGXPREEMPTIBLEWORKERCONFIG._serialized_end=4637
  _DATAPROCCLUSTERXCLUSTERCONFIGXSECURITYCONFIGXKERBEROSCONFIG._serialized_start=4640
  _DATAPROCCLUSTERXCLUSTERCONFIGXSECURITYCONFIGXKERBEROSCONFIG._serialized_end=5138
  _DATAPROCCLUSTERXCLUSTERCONFIGXSECURITYCONFIG._serialized_start=5141
  _DATAPROCCLUSTERXCLUSTERCONFIGXSECURITYCONFIG._serialized_end=5299
  _DATAPROCCLUSTERXCLUSTERCONFIGXSOFTWARECONFIG._serialized_start=5302
  _DATAPROCCLUSTERXCLUSTERCONFIGXSOFTWARECONFIG._serialized_end=5743
  _DATAPROCCLUSTERXCLUSTERCONFIGXSOFTWARECONFIG_OVERRIDEPROPERTIESENTRY._serialized_start=5635
  _DATAPROCCLUSTERXCLUSTERCONFIGXSOFTWARECONFIG_OVERRIDEPROPERTIESENTRY._serialized_end=5692
  _DATAPROCCLUSTERXCLUSTERCONFIGXSOFTWARECONFIG_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCCLUSTERXCLUSTERCONFIGXSOFTWARECONFIG_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCCLUSTERXCLUSTERCONFIGXWORKERCONFIGXACCELERATORS._serialized_start=5745
  _DATAPROCCLUSTERXCLUSTERCONFIGXWORKERCONFIGXACCELERATORS._serialized_end=5855
  _DATAPROCCLUSTERXCLUSTERCONFIGXWORKERCONFIGXDISKCONFIG._serialized_start=5858
  _DATAPROCCLUSTERXCLUSTERCONFIGXWORKERCONFIGXDISKCONFIG._serialized_end=5988
  _DATAPROCCLUSTERXCLUSTERCONFIGXWORKERCONFIG._serialized_start=5991
  _DATAPROCCLUSTERXCLUSTERCONFIGXWORKERCONFIG._serialized_end=6356
  _DATAPROCCLUSTERXCLUSTERCONFIG._serialized_start=6359
  _DATAPROCCLUSTERXCLUSTERCONFIG._serialized_end=7657
  _DATAPROCCLUSTERXTIMEOUTS._serialized_start=7659
  _DATAPROCCLUSTERXTIMEOUTS._serialized_end=7733
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXAUXILIARYSERVICESCONFIGXMETASTORECONFIG._serialized_start=7735
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXAUXILIARYSERVICESCONFIGXMETASTORECONFIG._serialized_end=7849
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXAUXILIARYSERVICESCONFIGXSPARKHISTORYSERVERCONFIG._serialized_start=7851
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXAUXILIARYSERVICESCONFIGXSPARKHISTORYSERVERCONFIG._serialized_end=7964
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXAUXILIARYSERVICESCONFIG._serialized_start=7967
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXAUXILIARYSERVICESCONFIG._serialized_end=8311
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXGKECLUSTERCONFIGXNODEPOOLTARGETXNODEPOOLCONFIGXAUTOSCALING._serialized_start=8314
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXGKECLUSTERCONFIGXNODEPOOLTARGETXNODEPOOLCONFIGXAUTOSCALING._serialized_end=8483
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXGKECLUSTERCONFIGXNODEPOOLTARGETXNODEPOOLCONFIGXCONFIG._serialized_start=8486
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXGKECLUSTERCONFIGXNODEPOOLTARGETXNODEPOOLCONFIGXCONFIG._serialized_end=8710
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXGKECLUSTERCONFIGXNODEPOOLTARGETXNODEPOOLCONFIG._serialized_start=8713
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXGKECLUSTERCONFIGXNODEPOOLTARGETXNODEPOOLCONFIG._serialized_end=9171
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXGKECLUSTERCONFIGXNODEPOOLTARGET._serialized_start=9174
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXGKECLUSTERCONFIGXNODEPOOLTARGET._serialized_end=9465
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXGKECLUSTERCONFIG._serialized_start=9468
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXGKECLUSTERCONFIG._serialized_end=9722
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXKUBERNETESSOFTWARECONFIG._serialized_start=9725
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXKUBERNETESSOFTWARECONFIG._serialized_end=10234
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXKUBERNETESSOFTWARECONFIG_COMPONENTVERSIONENTRY._serialized_start=10128
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXKUBERNETESSOFTWARECONFIG_COMPONENTVERSIONENTRY._serialized_end=10183
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXKUBERNETESSOFTWARECONFIG_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIGXKUBERNETESSOFTWARECONFIG_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIG._serialized_start=10237
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIGXKUBERNETESCLUSTERCONFIG._serialized_end=10613
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIG._serialized_start=10616
  _DATAPROCCLUSTERXVIRTUALCLUSTERCONFIG._serialized_end=10924
  _DATAPROCCLUSTER._serialized_start=10927
  _DATAPROCCLUSTER._serialized_end=11464
  _DATAPROCCLUSTER_LABELSENTRY._serialized_start=11419
  _DATAPROCCLUSTER_LABELSENTRY._serialized_end=11464
  _DATAPROCCLUSTERIAMBINDINGXCONDITION._serialized_start=11466
  _DATAPROCCLUSTERIAMBINDINGXCONDITION._serialized_end=11559
  _DATAPROCCLUSTERIAMBINDING._serialized_start=11562
  _DATAPROCCLUSTERIAMBINDING._serialized_end=11835
  _DATAPROCCLUSTERIAMMEMBERXCONDITION._serialized_start=11837
  _DATAPROCCLUSTERIAMMEMBERXCONDITION._serialized_end=11929
  _DATAPROCCLUSTERIAMMEMBER._serialized_start=11932
  _DATAPROCCLUSTERIAMMEMBER._serialized_end=12202
  _DATAPROCCLUSTERIAMPOLICY._serialized_start=12205
  _DATAPROCCLUSTERIAMPOLICY._serialized_end=12385
  _DATAPROCJOBXHADOOPCONFIGXLOGGINGCONFIG._serialized_start=12388
  _DATAPROCJOBXHADOOPCONFIGXLOGGINGCONFIG._serialized_end=12598
  _DATAPROCJOBXHADOOPCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_start=12544
  _DATAPROCJOBXHADOOPCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_end=12598
  _DATAPROCJOBXHADOOPCONFIG._serialized_start=12601
  _DATAPROCJOBXHADOOPCONFIG._serialized_end=12981
  _DATAPROCJOBXHADOOPCONFIG_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCJOBXHADOOPCONFIG_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCJOBXHIVECONFIG._serialized_start=12984
  _DATAPROCJOBXHIVECONFIG._serialized_end=13394
  _DATAPROCJOBXHIVECONFIG_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCJOBXHIVECONFIG_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCJOBXHIVECONFIG_SCRIPTVARIABLESENTRY._serialized_start=13340
  _DATAPROCJOBXHIVECONFIG_SCRIPTVARIABLESENTRY._serialized_end=13394
  _DATAPROCJOBXPIGCONFIGXLOGGINGCONFIG._serialized_start=13397
  _DATAPROCJOBXPIGCONFIGXLOGGINGCONFIG._serialized_end=13601
  _DATAPROCJOBXPIGCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_start=12544
  _DATAPROCJOBXPIGCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_end=12598
  _DATAPROCJOBXPIGCONFIG._serialized_start=13604
  _DATAPROCJOBXPIGCONFIG._serialized_end=14098
  _DATAPROCJOBXPIGCONFIG_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCJOBXPIGCONFIG_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCJOBXPIGCONFIG_SCRIPTVARIABLESENTRY._serialized_start=13340
  _DATAPROCJOBXPIGCONFIG_SCRIPTVARIABLESENTRY._serialized_end=13394
  _DATAPROCJOBXPLACEMENT._serialized_start=14100
  _DATAPROCJOBXPLACEMENT._serialized_end=14167
  _DATAPROCJOBXPRESTOCONFIGXLOGGINGCONFIG._serialized_start=14170
  _DATAPROCJOBXPRESTOCONFIGXLOGGINGCONFIG._serialized_end=14380
  _DATAPROCJOBXPRESTOCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_start=12544
  _DATAPROCJOBXPRESTOCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_end=12598
  _DATAPROCJOBXPRESTOCONFIG._serialized_start=14383
  _DATAPROCJOBXPRESTOCONFIG._serialized_end=14755
  _DATAPROCJOBXPRESTOCONFIG_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCJOBXPRESTOCONFIG_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCJOBXPYSPARKCONFIGXLOGGINGCONFIG._serialized_start=14758
  _DATAPROCJOBXPYSPARKCONFIGXLOGGINGCONFIG._serialized_end=14970
  _DATAPROCJOBXPYSPARKCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_start=12544
  _DATAPROCJOBXPYSPARKCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_end=12598
  _DATAPROCJOBXPYSPARKCONFIG._serialized_start=14973
  _DATAPROCJOBXPYSPARKCONFIG._serialized_end=15365
  _DATAPROCJOBXPYSPARKCONFIG_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCJOBXPYSPARKCONFIG_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCJOBXREFERENCE._serialized_start=15367
  _DATAPROCJOBXREFERENCE._serialized_end=15406
  _DATAPROCJOBXSCHEDULING._serialized_start=15408
  _DATAPROCJOBXSCHEDULING._serialized_end=15491
  _DATAPROCJOBXSPARKCONFIGXLOGGINGCONFIG._serialized_start=15494
  _DATAPROCJOBXSPARKCONFIGXLOGGINGCONFIG._serialized_end=15702
  _DATAPROCJOBXSPARKCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_start=12544
  _DATAPROCJOBXSPARKCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_end=12598
  _DATAPROCJOBXSPARKCONFIG._serialized_start=15705
  _DATAPROCJOBXSPARKCONFIG._serialized_end=16082
  _DATAPROCJOBXSPARKCONFIG_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCJOBXSPARKCONFIG_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCJOBXSPARKSQLCONFIGXLOGGINGCONFIG._serialized_start=16085
  _DATAPROCJOBXSPARKSQLCONFIGXLOGGINGCONFIG._serialized_end=16299
  _DATAPROCJOBXSPARKSQLCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_start=12544
  _DATAPROCJOBXSPARKSQLCONFIGXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_end=12598
  _DATAPROCJOBXSPARKSQLCONFIG._serialized_start=16302
  _DATAPROCJOBXSPARKSQLCONFIG._serialized_end=16787
  _DATAPROCJOBXSPARKSQLCONFIG_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCJOBXSPARKSQLCONFIG_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCJOBXSPARKSQLCONFIG_SCRIPTVARIABLESENTRY._serialized_start=13340
  _DATAPROCJOBXSPARKSQLCONFIG_SCRIPTVARIABLESENTRY._serialized_end=13394
  _DATAPROCJOBXTIMEOUTS._serialized_start=16789
  _DATAPROCJOBXTIMEOUTS._serialized_end=16843
  _DATAPROCJOB._serialized_start=16846
  _DATAPROCJOB._serialized_end=18073
  _DATAPROCJOB_LABELSENTRY._serialized_start=11419
  _DATAPROCJOB_LABELSENTRY._serialized_end=11464
  _DATAPROCJOB_STATUSENTRY._serialized_start=18028
  _DATAPROCJOB_STATUSENTRY._serialized_end=18073
  _DATAPROCJOBIAMBINDINGXCONDITION._serialized_start=18075
  _DATAPROCJOBIAMBINDINGXCONDITION._serialized_end=18164
  _DATAPROCJOBIAMBINDING._serialized_start=18167
  _DATAPROCJOBIAMBINDING._serialized_end=18431
  _DATAPROCJOBIAMMEMBERXCONDITION._serialized_start=18433
  _DATAPROCJOBIAMMEMBERXCONDITION._serialized_end=18521
  _DATAPROCJOBIAMMEMBER._serialized_start=18524
  _DATAPROCJOBIAMMEMBER._serialized_end=18785
  _DATAPROCJOBIAMPOLICY._serialized_start=18788
  _DATAPROCJOBIAMPOLICY._serialized_end=18963
  _DATAPROCMETASTORESERVICEXENCRYPTIONCONFIG._serialized_start=18965
  _DATAPROCMETASTORESERVICEXENCRYPTIONCONFIG._serialized_end=19025
  _DATAPROCMETASTORESERVICEXHIVEMETASTORECONFIGXKERBEROSCONFIGXKEYTAB._serialized_start=19027
  _DATAPROCMETASTORESERVICEXHIVEMETASTORECONFIGXKERBEROSCONFIGXKEYTAB._serialized_end=19117
  _DATAPROCMETASTORESERVICEXHIVEMETASTORECONFIGXKERBEROSCONFIG._serialized_start=19120
  _DATAPROCMETASTORESERVICEXHIVEMETASTORECONFIGXKERBEROSCONFIG._serialized_end=19339
  _DATAPROCMETASTORESERVICEXHIVEMETASTORECONFIG._serialized_start=19342
  _DATAPROCMETASTORESERVICEXHIVEMETASTORECONFIG._serialized_end=19692
  _DATAPROCMETASTORESERVICEXHIVEMETASTORECONFIG_CONFIGOVERRIDESENTRY._serialized_start=19638
  _DATAPROCMETASTORESERVICEXHIVEMETASTORECONFIG_CONFIGOVERRIDESENTRY._serialized_end=19692
  _DATAPROCMETASTORESERVICEXMAINTENANCEWINDOW._serialized_start=19694
  _DATAPROCMETASTORESERVICEXMAINTENANCEWINDOW._serialized_end=19780
  _DATAPROCMETASTORESERVICEXTIMEOUTS._serialized_start=19782
  _DATAPROCMETASTORESERVICEXTIMEOUTS._serialized_end=19865
  _DATAPROCMETASTORESERVICE._serialized_start=19868
  _DATAPROCMETASTORESERVICE._serialized_end=20727
  _DATAPROCMETASTORESERVICE_LABELSENTRY._serialized_start=11419
  _DATAPROCMETASTORESERVICE_LABELSENTRY._serialized_end=11464
  _DATAPROCMETASTORESERVICEIAMBINDINGXCONDITION._serialized_start=20729
  _DATAPROCMETASTORESERVICEIAMBINDINGXCONDITION._serialized_end=20831
  _DATAPROCMETASTORESERVICEIAMBINDING._serialized_start=20834
  _DATAPROCMETASTORESERVICEIAMBINDING._serialized_end=21130
  _DATAPROCMETASTORESERVICEIAMMEMBERXCONDITION._serialized_start=21132
  _DATAPROCMETASTORESERVICEIAMMEMBERXCONDITION._serialized_end=21233
  _DATAPROCMETASTORESERVICEIAMMEMBER._serialized_start=21236
  _DATAPROCMETASTORESERVICEIAMMEMBER._serialized_end=21529
  _DATAPROCMETASTORESERVICEIAMPOLICY._serialized_start=21532
  _DATAPROCMETASTORESERVICEIAMPOLICY._serialized_end=21726
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHADOOPJOBXLOGGINGCONFIG._serialized_start=21729
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHADOOPJOBXLOGGINGCONFIG._serialized_end=21969
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHADOOPJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_start=12544
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHADOOPJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_end=12598
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHADOOPJOB._serialized_start=21972
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHADOOPJOB._serialized_end=22397
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHADOOPJOB_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHADOOPJOB_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHIVEJOBXQUERYLIST._serialized_start=22399
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHIVEJOBXQUERYLIST._serialized_end=22465
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHIVEJOB._serialized_start=22468
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHIVEJOB._serialized_end=22998
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHIVEJOB_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHIVEJOB_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHIVEJOB_SCRIPTVARIABLESENTRY._serialized_start=13340
  _DATAPROCWORKFLOWTEMPLATEXJOBSXHIVEJOB_SCRIPTVARIABLESENTRY._serialized_end=13394
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOBXLOGGINGCONFIG._serialized_start=23001
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOBXLOGGINGCONFIG._serialized_end=23235
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_start=12544
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_end=12598
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOBXQUERYLIST._serialized_start=23237
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOBXQUERYLIST._serialized_end=23302
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOB._serialized_start=23305
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOB._serialized_end=23933
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOB_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOB_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOB_SCRIPTVARIABLESENTRY._serialized_start=13340
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPIGJOB_SCRIPTVARIABLESENTRY._serialized_end=13394
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPRESTOJOBXLOGGINGCONFIG._serialized_start=23936
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPRESTOJOBXLOGGINGCONFIG._serialized_end=24176
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPRESTOJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_start=12544
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPRESTOJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_end=12598
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPRESTOJOBXQUERYLIST._serialized_start=24178
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPRESTOJOBXQUERYLIST._serialized_end=24246
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPRESTOJOB._serialized_start=24249
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPRESTOJOB._serialized_end=24743
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPRESTOJOB_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPRESTOJOB_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPYSPARKJOBXLOGGINGCONFIG._serialized_start=24746
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPYSPARKJOBXLOGGINGCONFIG._serialized_end=24989
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPYSPARKJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_start=12544
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPYSPARKJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_end=12598
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPYSPARKJOB._serialized_start=24992
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPYSPARKJOB._serialized_end=25429
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPYSPARKJOB_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCWORKFLOWTEMPLATEXJOBSXPYSPARKJOB_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSCHEDULING._serialized_start=25431
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSCHEDULING._serialized_end=25532
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKJOBXLOGGINGCONFIG._serialized_start=25535
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKJOBXLOGGINGCONFIG._serialized_end=25773
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_start=12544
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_end=12598
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKJOB._serialized_start=25776
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKJOB._serialized_end=26198
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKJOB_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKJOB_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKRJOBXLOGGINGCONFIG._serialized_start=26201
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKRJOBXLOGGINGCONFIG._serialized_end=26441
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKRJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_start=12544
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKRJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_end=12598
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKRJOB._serialized_start=26444
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKRJOB._serialized_end=26824
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKRJOB_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKRJOB_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOBXLOGGINGCONFIG._serialized_start=26827
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOBXLOGGINGCONFIG._serialized_end=27072
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_start=12544
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOBXLOGGINGCONFIG_DRIVERLOGLEVELSENTRY._serialized_end=12598
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOBXQUERYLIST._serialized_start=27074
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOBXQUERYLIST._serialized_end=27144
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOB._serialized_start=27147
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOB._serialized_end=27771
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOB_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOB_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOB_SCRIPTVARIABLESENTRY._serialized_start=13340
  _DATAPROCWORKFLOWTEMPLATEXJOBSXSPARKSQLJOB_SCRIPTVARIABLESENTRY._serialized_end=13394
  _DATAPROCWORKFLOWTEMPLATEXJOBS._serialized_start=27774
  _DATAPROCWORKFLOWTEMPLATEXJOBS._serialized_end=28765
  _DATAPROCWORKFLOWTEMPLATEXJOBS_LABELSENTRY._serialized_start=11419
  _DATAPROCWORKFLOWTEMPLATEXJOBS_LABELSENTRY._serialized_end=11464
  _DATAPROCWORKFLOWTEMPLATEXPARAMETERSXVALIDATIONXREGEX._serialized_start=28767
  _DATAPROCWORKFLOWTEMPLATEXPARAMETERSXVALIDATIONXREGEX._serialized_end=28838
  _DATAPROCWORKFLOWTEMPLATEXPARAMETERSXVALIDATIONXVALUES._serialized_start=28840
  _DATAPROCWORKFLOWTEMPLATEXPARAMETERSXVALIDATIONXVALUES._serialized_end=28911
  _DATAPROCWORKFLOWTEMPLATEXPARAMETERSXVALIDATION._serialized_start=28914
  _DATAPROCWORKFLOWTEMPLATEXPARAMETERSXVALIDATION._serialized_end=29154
  _DATAPROCWORKFLOWTEMPLATEXPARAMETERS._serialized_start=29157
  _DATAPROCWORKFLOWTEMPLATEXPARAMETERS._serialized_end=29339
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXCLUSTERSELECTOR._serialized_start=29342
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXCLUSTERSELECTOR._serialized_end=29583
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXCLUSTERSELECTOR_CLUSTERLABELSENTRY._serialized_start=29531
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXCLUSTERSELECTOR_CLUSTERLABELSENTRY._serialized_end=29583
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXAUTOSCALINGCONFIG._serialized_start=29585
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXAUTOSCALINGCONFIG._serialized_end=29677
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXENCRYPTIONCONFIG._serialized_start=29679
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXENCRYPTIONCONFIG._serialized_end=29783
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXENDPOINTCONFIG._serialized_start=29786
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXENDPOINTCONFIG._serialized_end=30077
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXENDPOINTCONFIG_HTTPPORTSENTRY._serialized_start=2643
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXENDPOINTCONFIG_HTTPPORTSENTRY._serialized_end=2691
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXGCECLUSTERCONFIGXNODEGROUPAFFINITY._serialized_start=30079
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXGCECLUSTERCONFIGXNODEGROUPAFFINITY._serialized_end=30192
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXGCECLUSTERCONFIGXRESERVATIONAFFINITY._serialized_start=30195
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXGCECLUSTERCONFIGXRESERVATIONAFFINITY._serialized_end=30353
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXGCECLUSTERCONFIG._serialized_start=30356
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXGCECLUSTERCONFIG._serialized_end=31099
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXGCECLUSTERCONFIG_METADATAENTRY._serialized_start=3290
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXGCECLUSTERCONFIG_METADATAENTRY._serialized_end=3337
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXINITIALIZATIONACTIONS._serialized_start=31102
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXINITIALIZATIONACTIONS._serialized_end=31234
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXLIFECYCLECONFIG._serialized_start=31237
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXLIFECYCLECONFIG._serialized_end=31412
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXMASTERCONFIGXACCELERATORS._serialized_start=31415
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXMASTERCONFIGXACCELERATORS._serialized_end=31552
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXMASTERCONFIGXDISKCONFIG._serialized_start=31555
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXMASTERCONFIGXDISKCONFIG._serialized_end=31712
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXMASTERCONFIG._serialized_start=31715
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXMASTERCONFIG._serialized_end=32417
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXMASTERCONFIG_MANAGEDGROUPCONFIGENTRY._serialized_start=32360
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXMASTERCONFIG_MANAGEDGROUPCONFIGENTRY._serialized_end=32417
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSECONDARYWORKERCONFIGXACCELERATORS._serialized_start=32420
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSECONDARYWORKERCONFIGXACCELERATORS._serialized_end=32566
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSECONDARYWORKERCONFIGXDISKCONFIG._serialized_start=32569
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSECONDARYWORKERCONFIGXDISKCONFIG._serialized_end=32735
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSECONDARYWORKERCONFIG._serialized_start=32738
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSECONDARYWORKERCONFIG._serialized_end=33478
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSECONDARYWORKERCONFIG_MANAGEDGROUPCONFIGENTRY._serialized_start=32360
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSECONDARYWORKERCONFIG_MANAGEDGROUPCONFIGENTRY._serialized_end=32417
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSECURITYCONFIGXKERBEROSCONFIG._serialized_start=33481
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSECURITYCONFIGXKERBEROSCONFIG._serialized_end=33970
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSECURITYCONFIG._serialized_start=33973
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSECURITYCONFIG._serialized_end=34186
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSOFTWARECONFIG._serialized_start=34189
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSOFTWARECONFIG._serialized_end=34501
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSOFTWARECONFIG_PROPERTIESENTRY._serialized_start=5694
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXSOFTWARECONFIG_PROPERTIESENTRY._serialized_end=5743
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXWORKERCONFIGXACCELERATORS._serialized_start=34504
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXWORKERCONFIGXACCELERATORS._serialized_end=34641
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXWORKERCONFIGXDISKCONFIG._serialized_start=34644
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXWORKERCONFIGXDISKCONFIG._serialized_end=34801
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXWORKERCONFIG._serialized_start=34804
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXWORKERCONFIG._serialized_end=35506
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXWORKERCONFIG_MANAGEDGROUPCONFIGENTRY._serialized_start=32360
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIGXWORKERCONFIG_MANAGEDGROUPCONFIGENTRY._serialized_end=32417
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIG._serialized_start=35509
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTERXCONFIG._serialized_end=37017
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTER._serialized_start=37020
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTER._serialized_end=37345
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTER_LABELSENTRY._serialized_start=11419
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENTXMANAGEDCLUSTER_LABELSENTRY._serialized_end=11464
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENT._serialized_start=37348
  _DATAPROCWORKFLOWTEMPLATEXPLACEMENT._serialized_end=37590
  _DATAPROCWORKFLOWTEMPLATEXTIMEOUTS._serialized_start=37592
  _DATAPROCWORKFLOWTEMPLATEXTIMEOUTS._serialized_end=37659
  _DATAPROCWORKFLOWTEMPLATE._serialized_start=37662
  _DATAPROCWORKFLOWTEMPLATE._serialized_end=38327
  _DATAPROCWORKFLOWTEMPLATE_LABELSENTRY._serialized_start=11419
  _DATAPROCWORKFLOWTEMPLATE_LABELSENTRY._serialized_end=11464
# @@protoc_insertion_point(module_scope)
